#include<bits/stdc++.h>

using namespace std;
typedef long long ll;

template<typename TI, typename TF>
class generic_point {
public:
    TI x, y;

    generic_point() = default;

    generic_point(TI _x, TI _y) : x(_x), y(_y) {}

    generic_point<TI, TF> operator+(const generic_point<TI, TF>& other) const {
        return generic_point<TI, TF>(x + other.x, y + other.y);
    }

    generic_point<TI, TF> operator-(const generic_point<TI, TF>& other) const {
        return generic_point<TI, TF>(x - other.x, y - other.y);
    }

    generic_point<TI, TF> operator+() const {
        return *this;
    }

    generic_point<TI, TF> operator-() const {
        return generic_point<TI, TF>(-x, -y);
    }

    generic_point<TI, TF> operator*(TI k) const {
        return generic_point<TI, TF>(x * k, y * k);
    }

    template<typename T = TI>
    typename std::enable_if<std::is_floating_point<T>::value, generic_point<TI, TF>>::type
    operator/(TF k) const {
        return generic_point<TI, TF>(x / k, y / k);
    }

    TI operator*(const generic_point<TI, TF>& other) const {
        return x * other.x + y * other.y;
    }

    TI operator%(const generic_point<TI, TF>& other) const {
        return x * other.y - y * other.x;
    }

    TI lenSqr() const {
        return x * x + y * y;
    }

    TF len() const {
        return sqrt(lenSqr());
    }

    TI distSqr(const generic_point<TI, TF>& other) const {
        return (other - *this).lenSqr();
    }

    TF dist(const generic_point<TI, TF>& other) const {
        return sqrt(distSqr(other));
    }

    generic_point<TI, TF> norm() const {
        return *this / len();
    }

    // Counterclockwise rotation by 90 degrees
    generic_point<TI, TF> ort() const {
        return generic_point<TI, TF>(-y, x);
    }

    // Counterclockwise rotation by c = cos(alpha), s = sin(alpha)
    template<typename T = TI>
    typename std::enable_if<std::is_floating_point<T>::value, generic_point<TI, TF>>::type
    rot(TF c, TF s) const {
        return *this * c + ort() * s;
    }

    // Counterclockwise rotation by alpha
    generic_point<TI, TF> rot(TF alpha) const {
        return rot(cos(alpha), sin(alpha));
    }

    TF arg() const {
        return atan2(y, x);
    }

    int quad() const {
        if (x >= 0 && y >= 0) {
            return 1;
        } else if (x < 0 && y >= 0) {
            return 2;
        } else if (x < 0 && y < 0) {
            return 3;
        } else if (x >= 0 && y < 0) {
            return 4;
        }
        throw;
    }

    bool operator==(const generic_point<TI, TF>& other) const {
        return x == other.x && y == other.y;
    }

    bool operator!=(const generic_point<TI, TF>& other) const {
        return !(*this == other);
    }

    template<typename T = TI>
    typename std::enable_if<std::is_floating_point<T>::value>::type
    scan() {
        double _x, _y;
        scanf("%lf%lf", &_x, &_y);
        x = _x;
        y = _y;
    }

    template<typename T = TI>
    typename std::enable_if<std::is_integral<T>::value>::type
    scan() {
        ll _x, _y;
        scanf("%lld%lld", &_x, &_y);
        x = _x;
        y = _y;
    }

    template<typename T = TI>
    typename std::enable_if<std::is_floating_point<T>::value>::type
    print() {
        printf("%.10lf %.10lf\n", (double)x, (double)y);
    }

    template<typename T = TI>
    typename std::enable_if<std::is_integral<T>::value>::type
    print() {
        printf("%lld %lld\n", (ll)x, (ll)y);
    }
};

using point = generic_point<ll, double>;

bool inCycle(point cycle_koor, ll R, point p) {
    return (cycle_koor - p).lenSqr() <= R * R;
}

bool parallel(ll A1, ll B1, ll A2, ll B2) {
    return A1 * B2 == A2 * B1;
}

pair<ll, ll> get_line(point a, point b) {
    return {b.y - a.y, a.x - b.x};
}

void solve() {
    point cycle_koor;
    cycle_koor.scan();
    ll R;
    scanf("%lld", &R);

    ll A, B, C;
    scanf("%lld%lld%lld", &A, &B, &C);

    point first;
    first.scan();
    point second;
    second.scan();


    if (inCycle(cycle_koor, R, first) && inCycle(cycle_koor, R, second)) {
        cout << "YES\n";
    } else if (!inCycle(cycle_koor, R, first) && !inCycle(cycle_koor, R, second)) {
        pair<ll, ll> line = get_line(first, second);
        if (parallel(A, B, line.first, line.second)) {
            cout << "YES\n";
        } else {
            cout << "NO\n";
        }
    } else {
        if (inCycle(cycle_koor, R, first)) {
            swap(first, second);
        }
        C = -(A * first.x + B * first.y);
        ll dist = (A * cycle_koor.x + B * cycle_koor.y + C);
        if (dist * dist <= (A * A + B * B) * (cycle_koor - second).lenSqr()) {
            cout << "YES";
        } else {
            cout << "NO";
        }
    }
}

signed main() {
    ios_base::sync_with_stdio(0);
    cin.tie(0);
    int _ = 1;
    // cin >> _;
    for (int i = 0; i < _; i++) {
        solve();
    }
    return 0;
}

